@@ -11,7 +11,7 @@
 # ifdef HAVE_SETLOCALE
 #  include <clocale>
 # endif
-#endif				/* HAVE_XLOCALE */
+#endif
 
 #ifdef TTY_GID_SUPPORT
 # include <grp.h>
@@ -19,39 +19,12 @@
 
 /* ways to deal with getting/setting termios structure */
 
-#ifdef HAVE_TERMIOS_H
 /* termios interface */
-# ifdef TCSANOW			/* POSIX */
-#  define GET_TERMIOS(fd,tios)	tcgetattr (fd, tios)
-#  define SET_TERMIOS(fd,tios)		\
-        cfsetospeed (tios, BAUDRATE),	\
-        cfsetispeed (tios, BAUDRATE),	\
-        tcsetattr (fd, TCSANOW, tios)
-# else
-#  ifdef TIOCSETA
-#   define GET_TERMIOS(fd,tios)	ioctl (fd, TIOCGETA, tios)
-#   define SET_TERMIOS(fd,tios)		\
-        tios->c_cflag |= BAUDRATE,	\
-        ioctl (fd, TIOCSETA, tios)
-#  else
-#   define GET_TERMIOS(fd,tios)	ioctl (fd, TCGETS, tios)
-#   define SET_TERMIOS(fd,tios)		\
-        tios->c_cflag |= BAUDRATE,	\
-        ioctl (fd, TCSETS, tios)
-#  endif
-# endif
-# define SET_TTYMODE(fd,tios)		SET_TERMIOS (fd, tios)
-#else
-/* sgtty interface */
-
-# define SET_TTYMODE(fd,tt)				\
-        tt->sg.sg_ispeed = tt->sg.sg_ospeed = BAUDRATE,	\
-        ioctl (fd, TIOCSETP, & (tt->sg)),		\
-        ioctl (fd, TIOCSETC, & (tt->tc)),		\
-        ioctl (fd, TIOCSLTC, & (tt->lc)),		\
-        ioctl (fd, TIOCSETD, & (tt->line)),		\
-        ioctl (fd, TIOCLSET, & (tt->local))
-#endif				/* HAVE_TERMIOS_H */
+#define GET_TERMIOS(fd,tios)	tcgetattr (fd, tios)
+#define SET_TERMIOS(fd,tios)		\
+      cfsetospeed (tios, BAUDRATE),	\
+      cfsetispeed (tios, BAUDRATE),	\
+      tcsetattr (fd, TCSANOW, tios)
 
 /* use the fastest baud-rate */
 #ifdef B38400
