@@ -1,4 +1,4 @@
-// all resource indices, used by rxvt.h anf rxvtperl.xs
+// all resource indices, used by rxvt.h and rxvtperl.xs
 
   def (display_name)
   def (term_name)
@@ -6,7 +6,7 @@
   def (geometry)
   def (reverseVideo)
   def (color)
-  reserve (color, NRS_COLORS)
+  reserve (color, TOTAL_COLORS)
   def (font)
 #if ENABLE_STYLES
   def (boldFont)
@@ -16,17 +16,13 @@
 #endif
   def (name)
   def (title)
-#if defined (XPM_BACKGROUND) || (MENUBAR_MAX)
-  def (path)
-#endif
 #ifdef XPM_BACKGROUND
+  def (path)
   def (backgroundPixmap)
-#endif
-#if (MENUBAR_MAX)
-  def (menu)
 #endif
   def (loginShell)
   def (jumpScroll)
+  def (skipScroll)
 #ifdef HAVE_SCROLLBARS
   def (scrollBar)
   def (scrollBar_right)
@@ -64,12 +60,15 @@
   def (preeditType)
   def (inputMethod)
 #endif
-#ifdef TRANSPARENT
+#ifdef ENABLE_TRANSPARENCY
   def (transparent)
-  def (transparent_all)
+#endif
+#if XFT
+  def (depth)
 #endif
 #if ENABLE_FRILLS
   def (transient_for)
+  def (override_redirect)
   def (pty_fd)
   def (hold)
   def (ext_bwidth)
@@ -78,6 +77,7 @@
   def (lineSpace)
   def (cursorUnderline)
   def (skipBuiltinGlyphs)
+  def (urgentOnBell)
 #endif
 #if CURSOR_BLINK
   def (cursorBlink)
@@ -111,3 +111,10 @@
   def (perl_ext_2)
   def (perl_lib)
 #endif
+#if ISO_14755
+  def (iso14755_52)
+#endif
+#ifdef HAVE_AFTERIMAGE
+  def (blendtype)
+  def (blurradius)
+#endif
